Welcome to Kaczmarz Algorithms's documentation!
===============================================================

.. mdinclude:: ../README.md

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   Overview <self>
   reference/index

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
